Enum Source 

pub enum Source {
    DevCrash,
    DevMem,
    ProcKcore,
    Raw(PathBuf),
}

Variants



DevCrash

Provides a read-only view of physical memory. Access to memory using this device must be paged aligned and read one page at a time.

On RHEL based distributions, this device is frequently provided by default. A loadable kernel module version is available as part of the Linux utility crash: https://github.com/crash-utility/crash/tree/master/memory_driver



DevMem

Provides a read-write view of physical memory, though AVML opens it in a read-only fashion. Access to to memory using this device can be disabled using the kernel configuration options CONFIG_STRICT_DEVMEM or CONFIG_IO_STRICT_DEVMEM.

With CONFIG_STRICT_DEVMEM, only the first 1MB of memory can be accessed.



ProcKcore

Provides a virtual ELF coredump of kernel memory. This can be used to access physical memory.

If LOCKDOWN_KCORE is set in the kernel, then /proc/kcore may exist but is either inaccessible or doesn’t allow access to all of the kernel memory.



Raw(PathBuf)

User-specified path to a raw memory file